@@ -1,5 +1,8 @@
 import os
+import sys
+
 import requests
+
 from .conf import config
 
 def load(thing=None):
@@ -24,11 +27,16 @@ def _load_slashrc():
     _load_file_if_exists(os.path.expanduser(config.root.run.user_customization_file_path))
 
 def _load_local_slashrc():
-    _load_file_if_exists(os.path.expanduser(os.path.expanduser(config.root.run.local_customization_file_path)))
+    _load_file_if_exists(os.path.abspath("./.slashrc"))
 
 def _load_file_if_exists(path):
     if os.path.isfile(path):
-        _load_filename(path)
+        old_sys_path = sys.path[:]
+        sys.path.insert(0, os.path.dirname(path))
+        try:
+            _load_filename(path)
+        finally:
+            sys.path[:] = old_sys_path
 
 def _load_environment():
     loaded_url_or_file = os.environ.get("SLASH_SETTINGS")
